<?php
/**
 * Fichier gérant les autorisations du plugin
 *
 * @plugin     Vrdv
 * @copyright  2024
 * @author     Vincent CALLIES
 * @licence    GNU/GPL
 * @package    SPIP\Vrdv\Installation
 */

if (!defined('_ECRIRE_INC_VERSION')) return;
 
// declaration vide pour ce pipeline.
function vrdv_autoriser(){}
 
/**
 * Deux objets éditoriaux : 
 * - vrdvs
 * - vcalendriers
 */
 
// -----------------
// Objet Rendez-vous (vrdv)

// bouton de menu
function autoriser_vrdvs_menu_dist($faire, $type, $id, $qui, $opts){
	 return TRUE;
}

// bouton de menu Outils rapides
function autoriser_vrdvcreer_menu_dist($faire, $type, $id, $qui, $opt) {
	 return $qui['statut'] == '0minirezo' AND !$qui['restreint'];
}

// iconifier (mettre un logo)
function autoriser_vrdv_iconifier_dist($faire, $type, $id, $qui, $opt) {
	// pas de logo sur un rendez-vous : il faut qu'un rendez-vous reste un objet simple
	return FALSE;
}

// creer
function autoriser_vrdv_creer_dist($faire, $type, $id, $qui, $opt) {
	// donner l'autorisation de créer, sachant que le formulaire
	// prend le relai pour voir où
	return true;
}
 
// voir
function autoriser_vrdv_voir_dist($faire, $type, $id, $qui, $opt) {
	// l'admin peut tout
	if ( $qui['statut'] == '0minirezo' AND !$qui['restreint']) return TRUE;
	// l'auteur associé au calendrier peut voir le rendez-vous
	if ( $id_auteur = (int) $qui['id_auteur']
		and $id = (int) $id
		and $type == 'vrdv'
		and (
				( isset($opt['id_vcalendrier']) and $id_vcalendrier = (int) $opt['id_vcalendrier'] )
			or
				( $id_vcalendrier = sql_getfetsel('id_vcalendrier', 'spip_vrdvs', 'id_vrdv=' . $id) )
			)
		and include_spip('action/editer_liens')
		and objet_trouver_liens(['id_auteur' => $id_auteur], ['vcalendrier' => $id_vcalendrier])
	){
		return TRUE;
	}
	// si c'est une liste ($id = 0) il faut alors que l'$id_vcalendrier ait été précisé en option
	// et que l'auteur associé au calendrier indiqué pour voir les rendez-vous
	if (
		!$id = (int) $id
		and isset($opt['id_vcalendrier'])
		and $id_vcalendrier = (int) $opt['id_vcalendrier']
		and include_spip('action/editer_liens')
		and objet_trouver_liens(['id_auteur' => $id_auteur], ['vcalendrier' => $id_vcalendrier])
	){
		return TRUE;
	}
	return FALSE;
}
 
// modifier
function autoriser_vrdv_modifier_dist($faire, $type, $id, $qui, $opt) {
	// l'admin peut tout
	if ( $qui['statut'] == '0minirezo' AND !$qui['restreint']) return TRUE;
	// l'auteur associé au calendrier peut modifier le rendez-vous
	if ( $id_auteur = (int) $qui['id_auteur']
		and $id = (int) $id
		and $type == 'vrdv'
		and (
				( isset($opt['id_vcalendrier']) and $id_vcalendrier = (int) $opt['id_vcalendrier'] )
			or
				( $id_vcalendrier = sql_getfetsel('id_vcalendrier', 'spip_vrdvs', 'id_vrdv=' . $id) )
			)
		and include_spip('action/editer_liens')
		and objet_trouver_liens(['id_auteur' => $id_auteur], ['vcalendrier' => $id_vcalendrier])
	){
		return TRUE;
	}
	return FALSE;
}

// instituer (changer les statuts)
function autoriser_vrdv_instituer_dist ($faire, $type, $id, $qui, $opt) {
	// l'admin peut tout
	if ($qui['statut'] == '0minirezo' and !$qui['restreint']){
		return true;
	}
	// les autres ne peuvent ni archiver ni anonymiser 
	return !in_array($opt['statut'], ['archive', 'anonymise']);
}

// -----------------
// Objet Calendrier (vcalendrier)

// créer un vrdv dans un vcalendrier
function autoriser_vcalendrier_creervrdvdans_dist($faire, $type, $id, $qui, $opt) {
	// l'admin peut tout
	if ( $qui['statut'] == '0minirezo' AND !$qui['restreint']) return TRUE;
	// l'auteur associé à un calendrier peut y créer des rendez-vous 
	if ($id = (int) $id){
		return autoriser('voir', 'vrdv', 0, $qui, ['id_vcalendrier' => $id]);
	}
	return FALSE; 
}

// bouton de menu
function autoriser_vcalendriers_menu_dist($faire, $type, $id, $qui, $opts){
	 return $qui['statut'] == '0minirezo' AND !$qui['restreint'];
}

function autoriser_vcalendriersemaine_menu_dist($faire, $type, $id, $qui, $opts){
	 return TRUE;
 }
 
// creer
function autoriser_vcalendrier_creer_dist($faire, $type, $id, $qui, $opt) {
	 return $qui['statut'] == '0minirezo' AND !$qui['restreint']; 
}
 
// voir
function autoriser_vcalendrier_voir_dist($faire, $type, $id, $qui, $opt) {
	return autoriser('voir', 'vrdv', '0', $qui, ['id_calendrier' => $id]);
}
 
// modifier
function autoriser_vcalendrier_modifier_dist($faire, $type, $id, $qui, $opt) {
	 return $qui['statut'] == '0minirezo' AND !$qui['restreint']; 
}
 
 // supprimer
function autoriser_vcalendrier_supprimer_dist($faire, $type, $id, $qui, $opt) {
	return $qui['statut'] == '0minirezo' AND !$qui['restreint']; 
}
 
// associer (lier / delier)
function autoriser_associervcalendrier_dist($faire, $type, $id, $qui, $opt) {
	 return $qui['statut'] == '0minirezo' AND !$qui['restreint']; 
}

 